Changelog
=========

v0.1.1 (2022-02-09)
-------------------

Fixed
^^^^^
* Removed a few remaining calls to ``exit`` that would have led to the process exiting instead of
  returning with an error.

v0.1.0 (2022-02-06)
-------------------
Initial Release.
